// pages/analysis/analysis.js
const app = getApp();
const api = require('../../../api/api.js');
import * as echarts from '../../ec-canvas/echarts';
var dataList = [];

function setOption(chart) {
  let pageArr = getCurrentPages();
  let data = pageArr[pageArr.length - 1].data;
  const option = {
    tooltip: {
      trigger: 'axis'
    },
    xAxis: {
      type: 'category',
      boundaryGap: false,
      data: data.xData
    },
    yAxis: {
      show: false
    },
    series: [{
      data: data.yData,
      type: 'line',
      smooth: true,
      symbolSize: 10,
      lineStyle: {
        normal: {
          color: '#FF874E',
          width: 4
        }
      },
      itemStyle: {
        borderWidth: 3,
        borderColor: '',
        color: '#FF874E'
      },
      areaStyle: {
        color: {
          type: 'linear',
          x: 0,
          y: 0,
          x2: 0,
          y2: 1,
          colorStops: [{
              offset: 0,
              color: '#FF874E' // 0% 处的颜色
            },
            {
              offset: 1,
              color: '#FFFFFF' // 100% 处的颜色
            }
          ],
          globalCoord: false // 缺省为 false
        },
        opacity: 0.5
      }
    }]
  }
  chart.setOption(option);
}

Page({

  /**
   * 页面的初始数据
   */
  data: {
    navbarData: {
      showCapsule: 1, //是否显示左上角图标   1表示显示    0表示不显示
      title: '', //导航栏 中间的标题
      capsuleMode: 'navBack', //显示模式（navBack：返回上一页；navHome：返回首页）
    },
    fen: ["月", "季度", "年"],
    indexs: 0, //类型（0：月；1：季度；2：年）
    quarters: ['第1季度', '第2季度', '第3季度', '第4季度'], //季度列表
    years: ['2015', '2016', '2017', '2018', '2019', '2020', '2021', '2022', '2023', '2024', '2025', '2026', '2027', '2028', '2029', '2030'],
    ec: {
      lazyLoad: true // 延迟加载
    },
    show: false,
    currentDate: new Date().getTime(),
    year: new Date().getFullYear(),
    month: new Date().getMonth() + 1,
    quarter: 1, //季度
    shouzhi: 0, //收/支模式（0:收入,1:支出）

    xData: [], //X轴数据
    yData: [], //Y轴数据
    Income_list: [], //统计分析收入列表
    Income_money: '', //收入金额
    Expenditure_list: [], //统计分析支出列表
    Expenditure_money: '', //支出金额
    Buyer_ranking: [], //买家排名数组
    Commodity_ranking: [], //商品排名数组
    Help_sell_ranking: [], //帮卖排名数组
    Supplier_ranking: [], //供货商排名数组
    order_list: [], //订单收入数组

    isLoaded: false,
    isDisposed: false
  },
  // 切换月/季度/年
  qiehuan(e) {
    let that = this;
    that.setData({
      indexs: e.currentTarget.dataset.id
    })
    that.getIncome_list(); //获取统计分析收入
    that.getExpenditure_list(); //获取统计分析支出
    that.getBuyer_ranking(); //获取买家排名
    that.getCommodity_ranking(); //获取商品排名
    that.getHelp_sell_ranking(); //获取帮卖排名
    that.getSupplier_ranking(); //获取供货商排名
  },
  // 显示选择器
  showtime() {
    this.setData({
      show: true
    })
  },
  // 确认月
  oktime(e) {
    let that = this;
    let timec = e.detail;
    let date = new Date(timec);
    let year = date.getFullYear();
    let month = date.getMonth() + 1;
    that.setData({
      year: year,
      month: month,
      show: false
    })
    that.getIncome_list(); //获取统计分析收入
    that.getExpenditure_list(); //获取统计分析支出
    that.getBuyer_ranking(); //获取买家排名
    that.getCommodity_ranking(); //获取商品排名
    that.getHelp_sell_ranking(); //获取帮卖排名
    that.getSupplier_ranking(); //获取供货商排名
  },
  // 确认季度
  okquarter(e) {
    let that = this;
    let quarter = e.detail.index + 1;
    that.setData({
      quarter: quarter,
      show: false
    })
    that.getIncome_list();
    that.getExpenditure_list();
  },
  // 确认年
  okyear(e) {
    let that = this;
    let year = e.detail.value;
    that.setData({
      year: year,
      show: false
    })
    that.getIncome_list(); //获取统计分析收入
    that.getExpenditure_list(); //获取统计分析支出
    that.getBuyer_ranking(); //获取买家排名
    that.getCommodity_ranking(); //获取商品排名
    that.getHelp_sell_ranking(); //获取帮卖排名
    that.getSupplier_ranking(); //获取供货商排名
  },
  // 关闭选择器
  offtime() {
    this.setData({
      show: false
    })
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    let that = this;
    // 获取分析统计收入
    that.getIncome_list()
    // 获取买家排名
    that.getBuyer_ranking()
    // 获取商品排名
    that.getCommodity_ranking()
    // 获取帮卖排名
    that.getHelp_sell_ranking()
    // 获取供应商排名
    that.getSupplier_ranking()
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {
    this.ecComponent = this.selectComponent('#mychart-dom-bar');
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {

  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide: function () {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload: function () {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {

  },
  // 改变收支模式
  changeShouZhi(e) {
    let that = this;
    that.setData({
      shouzhi: e.currentTarget.dataset.type
    })
    if (that.data.shouzhi == 0) {
      that.getIncome_list()
    } else if (that.data.shouzhi == 1) {
      that.getExpenditure_list()
    }
  },
  // 获取统计分析收入
  getIncome_list() {
    let that = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    let year = that.data.year;
    let month = that.data.month;
    if (month < 10) {
      month = '0' + month
    }
    if (that.data.indexs == 0) {
      //月份模式
      wx.request({
        url: api.Income_list,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          month: year + '-' + month
        },
        success(res) {
          console.log(res);
          if (res.data.code === 1) {
            let arr = res.data.data.data;
            let xData = [];
            let yData = [];
            for (let i = 0; i < arr.length; i++) {
              xData.push(arr[i].date);
              yData.push(arr[i].price);
            }
            that.setData({
              Income_money: res.data.data.money,
              Income_list: res.data.data.data,
              xData,
              yData
            })
            dataList = res.data.data.data;
            // that.init_echarts(); //初始化图表
            that.init();
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    } else if (that.data.indexs == 1) {
      //季度模式
      wx.request({
        url: api.Income_list,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          quarter: that.data.quarter
        },
        success(res) {
          console.log(res);
          if (res.data.code === 1) {
            let arr = res.data.data.data;
            let xData = [];
            let yData = [];
            for (let i = 0; i < arr.length; i++) {
              xData.push(arr[i].date);
              yData.push(arr[i].price);
            }
            that.setData({
              Income_money: res.data.data.money,
              Income_list: res.data.data.data,
              xData,
              yData
            })
            dataList = res.data.data.data;
            // that.init_echarts(); //初始化图表
            that.init();
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    } else if (that.data.indexs == 2) {
      //年份模式
      wx.request({
        url: api.Income_list,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          year: year
        },
        success(res) {
          console.log(res);
          if (res.data.code === 1) {
            let arr = res.data.data.data;
            let xData = [];
            let yData = [];
            for (let i = 0; i < arr.length; i++) {
              xData.push(arr[i].date);
              yData.push(arr[i].price);
            }
            that.setData({
              Income_money: res.data.data.money,
              Income_list: res.data.data.data,
              xData,
              yData
            })
            dataList = res.data.data.data;
            // that.init_echarts(); //初始化图表
            that.init();
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    }
  },
  // 获取统计分析支出
  getExpenditure_list() {
    let that = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    let year = that.data.year;
    let month = that.data.month;
    if (month < 10) {
      month = '0' + month
    }
    if (that.data.indexs == 0) {
      //月份模式
      wx.request({
        url: api.Expenditure_list,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          month: year + '-' + month
        },
        success(res) {
          console.log(res);
          if (res.data.code === 1) {
            let arr = res.data.data.data;
            let xData = [];
            let yData = [];
            for (let i = 0; i < arr.length; i++) {
              xData.push(arr[i].date);
              yData.push(arr[i].price);
            }
            that.setData({
              Expenditure_money: res.data.data.money,
              Expenditure_list: res.data.data.data,
              xData,
              yData
            })
            dataList = res.data.data.data;
            // that.init_echarts(); //初始化图表
            that.init();
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    } else if (that.data.indexs == 1) {
      //季度模式
      wx.request({
        url: api.Expenditure_list,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          quarter: that.data.quarter
        },
        success(res) {
          console.log(res);
          if (res.data.code === 1) {
            let arr = res.data.data.data;
            let xData = [];
            let yData = [];
            for (let i = 0; i < arr.length; i++) {
              xData.push(arr[i].date);
              yData.push(arr[i].price);
            }
            that.setData({
              Expenditure_money: res.data.data.money,
              Expenditure_list: res.data.data.data,
              xData,
              yData
            })
            dataList = res.data.data.data;
            // that.init_echarts(); //初始化图表
            that.init();
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    } else if (that.data.indexs == 2) {
      //年份模式
      wx.request({
        url: api.Expenditure_list,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          year: year
        },
        success(res) {
          console.log(res);
          if (res.data.code === 1) {
            let arr = res.data.data.data;
            let xData = [];
            let yData = [];
            for (let i = 0; i < arr.length; i++) {
              xData.push(arr[i].date);
              yData.push(arr[i].price);
            }
            that.setData({
              Expenditure_money: res.data.data.money,
              Expenditure_list: res.data.data.data,
              xData,
              yData
            })
            dataList = res.data.data.data;
            // that.init_echarts(); //初始化图表
            that.init();
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    }
  },
  // 获取买家排名
  getBuyer_ranking() {
    let that = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    let year = that.data.year;
    let month = that.data.month;
    if (month < 10) {
      month = '0' + month
    }
    if (that.data.indexs == 0) {
      //月份模式
      wx.request({
        url: api.Buyer_ranking,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          month: year + '-' + month
        },
        success(res) {
          // console.log(res);
          if (res.data.code === 1) {
            that.setData({
              Buyer_ranking: res.data.data.slice(0, 3)
            })
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    } else if (that.data.indexs == 1) {
      //季度模式
    } else if (that.data.indexs == 2) {
      //年份模式
      wx.request({
        url: api.Buyer_ranking,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          year: year
        },
        success(res) {
          // console.log(res);
          if (res.data.code === 1) {
            that.setData({
              Buyer_ranking: res.data.data.slice(0, 3)
            })
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    }
  },
  // 获取商品排名
  getCommodity_ranking() {
    let that = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    let year = that.data.year;
    let month = that.data.month;
    if (month < 10) {
      month = '0' + month
    }
    if (that.data.indexs == 0) {
      //月份模式
      wx.request({
        url: api.Commodity_ranking,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          month: year + '-' + month
        },
        success(res) {
          // console.log(res);
          if (res.data.code === 1) {
            that.setData({
              Commodity_ranking: res.data.data.slice(0, 3)
            })
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    } else if (that.data.indexs == 1) {
      //季度模式
    } else if (that.data.indexs == 2) {
      //年份模式
      wx.request({
        url: api.Commodity_ranking,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          year: year
        },
        success(res) {
          // console.log(res);
          if (res.data.code === 1) {
            that.setData({
              Commodity_ranking: res.data.data.slice(0, 3)
            })
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    }
  },
  // 获取帮卖排名
  getHelp_sell_ranking() {
    let that = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    let year = that.data.year;
    let month = that.data.month;
    if (month < 10) {
      month = '0' + month
    }
    if (that.data.indexs == 0) {
      //月份模式
      wx.request({
        url: api.Help_sell_ranking,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          month: year + '-' + month
        },
        success(res) {
          // console.log(res);
          if (res.data.code === 1) {
            that.setData({
              Help_sell_ranking: res.data.data.slice(0, 3)
            })
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    } else if (that.data.indexs == 1) {
      //季度模式
    } else if (that.data.indexs == 2) {
      //年份模式
      wx.request({
        url: api.Help_sell_ranking,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          year: year
        },
        success(res) {
          // console.log(res);
          if (res.data.code === 1) {
            that.setData({
              Help_sell_ranking: res.data.data.slice(0, 3)
            })
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    }
  },
  // 获取供货商排名
  getSupplier_ranking() {
    let that = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    let year = that.data.year;
    let month = that.data.month;
    if (month < 10) {
      month = '0' + month
    }
    if (that.data.indexs == 0) {
      //月份模式
      wx.request({
        url: api.Supplier_ranking,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          month: year + '-' + month
        },
        success(res) {
          // console.log(res);
          if (res.data.code === 1) {
            that.setData({
              Supplier_ranking: res.data.data.slice(0, 3)
            })
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    } else if (that.data.indexs == 1) {
      //季度模式
    } else if (that.data.indexs == 2) {
      //年份模式
      wx.request({
        url: api.Supplier_ranking,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        data: {
          year: year
        },
        success(res) {
          // console.log(res);
          if (res.data.code === 1) {
            that.setData({
              Supplier_ranking: res.data.data.slice(0, 3)
            })
          } else {
            wx.showToast({
              title: res.data.msg,
              mask: true,
              icon: 'none'
            })
          }
        },
        fail(err) {
          wx.showToast({
            title: '发起网络请求失败',
            icon: 'none',
            mask: true
          })
        },
        complete() {
          wx.hideLoading()
        }
      })
    }
  },
  navgo(e) {
    let url = e.currentTarget.dataset.url
    wx.navigateTo({
      url: url,
    })
  },
  // 初始化图表
  init_echarts() {
    let that = this;
    that.ecComponent.init((canvas, width, height, dpr) => {
      // 初始化图表
      const Chart = echarts.init(canvas, null, {
        width: width,
        height: height,
        devicePixelRatio: dpr // new
      })
      Chart.setOption(that.getOption());
      return Chart;
    })
  },
  // 图表配置项
  getOption() {
    let that = this;
    var option = {
      tooltip: {
        trigger: 'axis'
      },
      xAxis: {
        type: 'category',
        boundaryGap: false,
        data: that.data.xData
      },
      yAxis: {
        show: false
      },
      series: [{
        data: that.data.yData,
        type: 'line',
        smooth: true,
        symbolSize: 10,
        lineStyle: {
          normal: {
            color: '#FF874E',
            width: 4
          }
        },
        itemStyle: {
          borderWidth: 3,
          borderColor: '',
          color: '#FF874E'
        },
        areaStyle: {
          color: {
            type: 'linear',
            x: 0,
            y: 0,
            x2: 0,
            y2: 1,
            colorStops: [{
                offset: 0,
                color: '#FF874E' // 0% 处的颜色
              },
              {
                offset: 1,
                color: '#FFFFFF' // 100% 处的颜色
              }
            ],
            globalCoord: false // 缺省为 false
          },
          opacity: 0.5
        }
      }]
    }
    return option;
  },

  // 获取数据后初始化图表
  init: function () {
    this.ecComponent.init((canvas, width, height, dpr) => {
      // 获取组件的 canvas、width、height 后的回调函数
      // 在这里初始化图表
      const chart = echarts.init(canvas, null, {
        width: width,
        height: height,
        devicePixelRatio: dpr // new
      });
      setOption(chart);

      // 将图表实例绑定到 this 上，可以在其他成员函数（如 dispose）中访问
      this.chart = chart;

      this.setData({
        isLoaded: true,
        isDisposed: false
      });

      // 注意这里一定要返回 chart 实例，否则会影响事件处理等
      return chart;
    });
  },
  dispose: function () {
    if (this.chart) {
      this.chart.dispose();
    }
    this.setData({
      isDisposed: true
    });
  }
})