// pages/orderdetail/orderdetail.js
const app = getApp();
const api = require('../../api/api');
Page({

  /**
   * 页面的初始数据
   */
  data: {
    navbarData: {
      showCapsule: 1, //是否显示左上角图标   1表示显示    0表示不显示
      title: '', //导航栏 中间的标题
      capsuleMode: 'navBack', //显示模式（navBack：返回上一页；navHome：返回首页）
    },
    orderStatus: 0, //订单状态/类型（0：交易完成；1：交易已取消；2：待取货；3：退款成功；4：待支付；）
    /* 组件参数 */
    showPopup: false, //显示确认框
    showPopupQRCode: false, //显示二维码
    /* 表单参数 */
    id: 0, //订单id
    order_info: {}, //订单信息
    user_info: {}, //用户信息
    commodity_list: [], //评论信息

    /* 支付相关 */
    showPayTypePicker: false, //显示支付方式选择器
    payTypes: [], //支付方式列表
    payType: [0], //支付方式
    showEMTPopup: false, //显示EMT支付弹出层

    /* EMT支付 */
    head_email: '', //团长邮箱
    order_number: '', //订单编号

    /* 修改订单 */
    genders: ['男士', '女士'],
    genderIndex: 0,
    consignee: '', //收货人姓名
    phone: '', //收货人手机号
    receiving_address: '', //收货人地址

    wxpayservice: '', //微信支付手续费
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.setData({
      id: Number(options.id)
    })
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {
    let that = this;
    // 获取订单详情
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wx.request({
      url: api.Order_info,
      header: {
        'Authorization': wx.getStorageSync('token')
      },
      data: {
        id: that.data.id
      },
      method: 'POST',
      success(res) {
        console.log(res);
        if (res.data.code === 1) {
          that.setData({
            order_info: res.data.data.order_info,
            user_info: res.data.data.user_info,
            commodity_list: res.data.data.commodity_list
          })
        } else {
          wx.showToast({
            title: res.data.msg,
            mask: true,
            icon: 'none'
          })
        }
      },
      fail(err) {
        wx.showToast({
          title: '发起网络请求失败',
          icon: 'none',
          mask: true
        })
      },
      complete() {
        wx.hideLoading()
      }
    })
  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide: function () {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload: function () {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    let order_id = this.data.order_info.id; //订单ID
    return {
      title: '订单分享',
      path: '/pages/orderdetail/orderdetail?id=' + order_id,
      imageUrl: 'https://s4.ax1x.com/2021/12/29/TccgfK.jpg'
    }
  },
  // 联系团长
  callHead() {
    wx.makePhoneCall({
      phoneNumber: this.data.user_info.phone
    })
  },
  // 显示二维码
  openPopupQRCode() {
    this.setData({
      showPopupQRCode: true
    })
  },
  // 取消订单
  cancelOrder() {
    this.setData({
      showPopup: true
    })
  },
  // 申请退款
  requestRefund() {
    wx.navigateTo({
      url: '/pages/requestrefund/requestrefund?id=' + this.data.order_info.id,
    })
  },
  // 关闭弹出层
  closePopup() {
    this.setData({
      showPopup: false,
      showPopupQRCode: false
    })
  },
  // 仍要取消
  confirmCancel() {
    // console.log('仍要取消');
    let that = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wx.request({
      url: api.Order_cancel,
      header: {
        'Authorization': wx.getStorageSync('token')
      },
      method: 'POST',
      data: {
        id: that.data.order_info.id
      },
      success(res) {
        wx.hideLoading()
        console.log(res);
        if (res.data.code === 1) {
          wx.showToast({
            title: '取消成功',
            mask: true,
            success() {
              setTimeout(() => {
                that.setData({
                  showPopup: false
                })
                wx.reLaunch({
                  url: '/pages/index/index',
                })
              }, 1500)
            }
          })
        } else {
          wx.showToast({
            title: res.data.msg,
            mask: true,
            icon: 'none'
          })
        }
      },
      fail(err) {
        wx.hideLoading()
        wx.showToast({
          title: '发起网络请求失败',
          icon: 'none',
          mask: true
        })
      },
      complete() {
        // wx.hideLoading()
      }
    })
  },
  // 修改订单信息
  changeOrder() {
    this.setData({
      consignee: this.data.order_info.consignee,
      phone: this.data.order_info.phone,
      receiving_address: this.data.order_info.receiving_address,
      genderIndex: this.data.order_info.gender,
      showModifyOrder: true,
      showPopup: false
    })
  },
  // 确认收货
  confirmReceipt() {
    let that = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wx.request({
      url: api.Order_receiving,
      header: {
        'Authorization': wx.getStorageSync('token')
      },
      method: 'POST',
      data: {
        id: that.data.order_info.id
      },
      success(res) {
        wx.hideLoading()
        console.log(res);
        if (res.data.code === 1) {
          wx.showToast({
            title: '收货成功',
            mask: true,
            success() {
              setTimeout(() => {
                wx.reLaunch({
                  url: '/pages/index/index',
                })
              }, 1500)
            }
          })
        } else {
          wx.showToast({
            title: res.data.msg,
            mask: true,
            icon: 'none'
          })
        }
      },
      fail(err) {
        wx.hideLoading()
        wx.showToast({
          title: '发起网络请求失败',
          icon: 'none',
          mask: true
        })
      },
      complete() {
        // wx.hideLoading()
      }
    })
  },
  // 复制订单号
  copyOrderNumber() {
    wx.setClipboardData({
      data: this.data.order_info.order_number
    })
  },
  // 去支付(打开支付方式弹出层)
  openPayTypePicker() {
    // 获取支付方式列表
    let that = this;
    let order_id = that.data.order_info.id;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wx.request({
      url: api.Order_payment_method,
      header: {
        'Authorization': wx.getStorageSync('token')
      },
      data: {
        id: Number(order_id)
      },
      method: 'POST',
      success(res) {
        console.log(res);
        if (res.data.code === 1) {
          that.setData({
            payTypes: res.data.data,
            showPayTypePicker: true
          })
        } else {
          wx.showToast({
            title: res.data.msg,
            mask: true,
            icon: 'none'
          })
        }
      },
      fail(err) {
        wx.showToast({
          title: '发起网络请求失败',
          icon: 'none',
          mask: true
        })
      },
      complete() {
        wx.hideLoading()
      }
    })
  },
  // 关闭支付方式弹出层
  closePayTypePicker() {
    this.setData({
      showPayTypePicker: false
    })
  },
  // 支付方式改变
  payTypeChanged(e) {
    this.setData({
      payType: e.detail.value
    })
  },
  // 确认支付
  confirmPay() {
    let that = this;
    let payType = that.data.payTypes[that.data.payType[0]]; //支付方式
    let id = that.data.order_info.id; //订单ID
    let payment_method = payType.payment_method; //支付方式（0微信支付，1EMT支付，2线下支付）
    let payment_price = that.data.order_info.payment_amount; //支付金额
    // 如果支付方式为微信支付-获取微信支付手续费
    if (payType.payment_name == '微信支付') {
      wx.showLoading({
        title: '加载中',
        mask: true
      })
      wx.request({
        url: api.Service,
        header: {
          'Authorization': wx.getStorageSync('token')
        },
        method: 'POST',
        success(res) {
          wx.hideLoading();
          // console.log(res);
          that.setData({
            wxpayservice: Number(res.data.data)
          })
          payment_price = payment_price * (1 + that.data.wxpayservice);
          payment_price = payment_price.toFixed(2);
          that.zhenDePay(id, payment_method, payment_price);
        },
        fail(err) {
          wx.hideLoading()
        }
      })
    } else {
      that.zhenDePay(id, payment_method, payment_price);
    }
  },
  // 真的要支付吗？在这里？就现在？
  zhenDePay(id, payment_method, payment_price) {
    let that = this;
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wx.request({
      url: api.Order_payment,
      header: {
        'Authorization': wx.getStorageSync('token')
      },
      data: {
        id: Number(id),
        payment_method: Number(payment_method),
        payment_price: payment_price
      },
      method: 'POST',
      success(res) {
        wx.hideLoading()
        console.log(res);
        if (res.data.code === 1) {
          if (res.data.msg == 'EMT支付') {
            that.setData({
              head_email: res.data.data.email,
              order_number: res.data.data.order_number
            })
            that.openEMTPopup()
          }
          if (res.data.msg == '线下支付') {
            that.setData({
              showPayTypePicker: false
            })
            wx.navigateTo({
              url: '/pages/orderdetail/orderdetail?id=' + id,
            })
          }
          if (res.data.msg == '微信支付') {
            wx.requestPayment({
              appId: res.data.data.payParams.appId,
              nonceStr: res.data.data.payParams.nonceStr,
              package: res.data.data.payParams.package,
              paySign: res.data.data.payParams.paySign,
              timeStamp: res.data.data.payParams.timeStamp,
              signType: res.data.data.payParams.signType,
              success(res) {
                wx.hideLoading()
                console.log(res);
                wx.showToast({
                  title: '支付成功',
                  mask: true,
                  success() {
                    setTimeout(() => {
                      that.setData({
                        showPayTypePicker: false
                      })
                      wx.navigateTo({
                        url: '/pages/orderdetail/orderdetail?id=' + id,
                      })
                    }, 1500)
                  }
                })
              },
              fail(res) {
                wx.hideLoading()
                console.log(res);
                if (res.errMsg.search('cancel')) {
                  wx.showToast({
                    title: '用户取消支付',
                    icon: 'error',
                    mask: true
                  })
                } else if (res.errMsg.search('offline')) {
                  wx.showToast({
                    title: '网络断开连接',
                    icon: 'error',
                    mask: true
                  })
                }
              }
            })
          }
        } else {
          wx.showToast({
            title: res.data.msg,
            mask: true,
            icon: 'none'
          })
        }
      },
      fail(err) {
        wx.hideLoading()
        wx.showToast({
          title: '发起网络请求失败',
          icon: 'none',
          mask: true
        })
      },
      complete() {
        // wx.hideLoading()
      }
    })
  },
  // 打开EMT支付弹出层
  openEMTPopup() {
    this.setData({
      showPayTypePicker: false,
      showEMTPopup: true
    })
  },
  // 关闭EMT支付弹出层
  closeEMTPopup() {
    this.setData({
      showEMTPopup: false
    })
  },
  // EMT已支付
  EMTpaid() {
    let id = this.data.order_info.id; //订单ID
    wx.navigateTo({
      url: '/pages/orderdetail/orderdetail?id=' + id,
    })
  },
  /* 修改订单相关接口 */
  // 输入姓名
  inputConsignee(e) {
    this.setData({
      consignee: e.detail.value
    })
  },
  // 输入手机号
  inputPhone(e) {
    this.setData({
      phone: e.detail.value
    })
  },
  // 输入地址
  inputAddress(e) {
    this.setData({
      receiving_address: e.detail.value
    })
  },
  // 选择性别
  selectGender(e) {
    this.setData({
      genderIndex: e.currentTarget.dataset.index
    })
  },
  // 修改订单
  confirmModify() {
    let that = this;
    if (that.data.consignee == '') {
      wx.showToast({
        title: '姓名未录入',
        icon: 'none',
        mask: true
      })
      return
    }
    if (that.data.phone == '') {
      wx.showToast({
        title: '手机号未录入',
        icon: 'none',
        mask: true
      })
      return
    }
    if (that.data.receiving_address == '') {
      wx.showToast({
        title: '地址未录入',
        icon: 'none',
        mask: true
      })
      return
    }
    wx.showLoading({
      title: '提交中',
      mask: true
    })
    wx.request({
      url: api.Order_edit_info,
      header: {
        'Authorization': wx.getStorageSync('token')
      },
      method: 'POST',
      data: {
        id: that.data.order_info.id,
        consignee: that.data.consignee,
        phone: that.data.phone,
        receiving_address: that.data.receiving_address,
        gender: that.data.genderIndex
      },
      success(res) {
        wx.hideLoading()
        console.log(res);
        if (res.data.code === 1) {
          wx.showToast({
            title: '提交成功',
            mask: true,
            success() {
              setTimeout(() => {
                wx.reLaunch({
                  url: '/pages/index/index',
                })
              }, 1500)
            }
          })
        } else {
          wx.showToast({
            title: res.data.msg,
            mask: true,
            icon: 'none'
          })
        }
      },
      fail(err) {
        wx.hideLoading()
        wx.showToast({
          title: '发起网络请求失败',
          icon: 'none',
          mask: true
        })
      },
      complete() {
        // wx.hideLoading()
      }
    })
  },
  // 关闭弹窗
  closeModifyOrder() {
    this.setData({
      showModifyOrder: false
    })
  },
})