const formatTime = date => {
  const year = date.getFullYear()
  const month = date.getMonth() + 1
  const day = date.getDate()
  const hour = date.getHours()
  const minute = date.getMinutes()
  const second = date.getSeconds()

  return `${[year, month, day].map(formatNumber).join('/')} ${[hour, minute, second].map(formatNumber).join(':')}`
}

const formatNumber = n => {
  n = n.toString()
  return n[1] ? n : `0${n}`
}

const throttle = (fn, wait = 0) => {
  let lastTime = null
  return function () {
    let curTime = new Date()
    // 距离下次触发fn还需等待的时间(如果没有lastTime说明是第一次，可以表示执行，即等待时间为0
    let remainTime = lastTime ? wait - (curTime - lastTime) : 0
    if (remainTime <= 0 || remainTime > wait) {
      lastTime = curTime
      return fn.apply(this, arguments)
    }
  }
}

/*
防抖函数：一个需要频繁触发的函数，在规定时间内，只让最后一次生效，前面的不生效
*/
/**
 * 防抖函数
 * @param fn 要被节流的函数
 * @param delay 规定的时间
 */
const debounce = function(fn, delay) {
  // 记录上一次的延时器
  let timer = null;
  return function () {
    // 清除上一次延时器
    clearTimeout(timer);
    // 重新设置新的延时器
    timer = setTimeout(function () {
      // 修正this指向问题
      fn.apply(this);
    }, delay)
  }
}

module.exports = {
  formatTime,
  throttle,
  debounce
}